/*
 * Arguments for a Csound task
 *
 * Copyright (c) 2003 by John D. Ramsdell. All rights reserved.
 *
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _ARGS_H
#define _ARGS_H

// If this is changed, arrays in the main application must be changed too.
enum Format {
  NO_FORMAT,
  AIFF_FORMAT,
  WAVE_FORMAT,
  IRCAM_FORMAT,
  RAW_FORMAT,
};

enum Output_size {
  NO_SIZE,
  UNSIGNED_EIGHT_SIZE,
  SIGNED_EIGHT_SIZE,
  SHORT_SIZE,
  TWENTY_FOUR_SIZE,
  THIRTY_TWO_SIZE,
  FLOAT_SIZE,
};

enum Graphics_option {
  FULL_GRAPHICS,
  POSTSCRIPT_GRAPHICS,
  ASCII_GRAPHICS,
  NO_GRAPHICS,
};

// Contains the digested representation of command line arguments.
class Args
{
public:
  Args();
  void clear();
  int parse(const wxFileName&, const wxArrayString&);
  void usage();
  wxArrayString get_command_line(const wxFileName&);
  void set_handler(wxEvtHandler *);
  void set_id(wxWindowID id);
  wxFileName get_orchestra() const;
  wxFileName get_orchestra(const wxFileName&) const;
  void set_orchestra(const wxFileName&);
  wxFileName get_score() const;
  wxFileName get_score(const wxFileName&) const;
  void set_score(const wxFileName&);
  wxFileName get_output() const;
  wxFileName get_output(const wxFileName&) const;
  void set_output(const wxFileName&);
  wxFileName get_log() const;
  wxFileName get_log(const wxFileName&) const;
  void set_log(const wxFileName&);
  Format get_format() const;
  void set_format(Format format);
  Graphics_option get_graphics_option() const;
  void set_graphics_option(Graphics_option);
  Output_size get_output_size() const;
  void set_output_size(Output_size);
  bool get_no_peak_chunks() const;
  void set_no_peak_chunks(bool);
  bool get_play_after_rendering() const;
  void set_play_after_rendering(bool);
  bool get_verbose() const;
  void set_verbose(bool);
  bool get_cscore() const;
  void set_cscore(bool);
  bool get_init_time_only() const;
  void set_init_time_only(bool);
  bool get_no_sound() const;
  void set_no_sound(bool);
  bool get_notify() const;
  void set_notify(bool);
  bool get_rewrite_header() const;
  void set_rewrite_header(bool);
  bool get_list_opcodes() const;
  void set_list_opcodes(bool);
  wxString get_message_level() const;
  void set_message_level(const wxString&);
private:
  void update() const;
  wxEvtHandler *m_handler;
  wxWindowID m_id;
  wxFileName m_orchestra;
  wxFileName m_score;
  wxFileName m_output;
  wxFileName m_log;
  Format m_format;
  Graphics_option m_graphics;
  Output_size m_output_size;
  bool m_no_peak_chunks;
  bool m_play_after_rendering;
  bool m_verbose;
  bool m_cscore;
  bool m_init_time_only;
  bool m_no_sound;
  bool m_notify;
  bool m_rewrite_header;
  bool m_list_opcodes;
  wxString m_message_level;
};

// Constructs the format used to store args in a file.
wxString enquote(const wxArrayString&);

// Convert the format used to store args in a file to an array of strings.
wxArrayString dequote(const wxString&);

#endif
