/*
 * A simple program to place a text file into a C string.
 *
 * Copyright (c) 2003 by John D. Ramsdell. All rights reserved.
 *
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <stdio.h>

static int usage(char *program)
{
  fprintf(stderr, "Usage: %s [ input [ output ] ]\n", program);
  return 1;
}

int main(int argc, char **argv)
{
  int c;
  char *filename = 0;

  /* reopen stdin and stdout from command line args if given */
  switch (argc) {
  case 3:
    filename = argv[2];		/* reopen later */
    /* fall thru okay */
  case 2:
    if (argv[1][0] == '-') {
      if (argv[1][1])		/* no flags recognized */
	return usage(argv[0]);
    }
    else if (!freopen(argv[1], "r", stdin)) {
      fprintf(stderr, "Failed to open %s for reading\n", argv[1]);
      return 1;
    }
    if (filename) {	  /* give stdin reopen chance to fail first */
      if (!freopen(argv[2], "w", stdout)) {
	fprintf(stderr, "Failed to open %s for writing\n", filename);
	return 1;
      }
    }
    /* fall thru okay */
  case 1:
    break;
  default:
    return usage(argv[0]);
  }

  printf("static const char string[] =\n\"");

  while ((c = getc(stdin)) != EOF) {
    switch (c) {
    case '\n':
      printf("\\n\"\n\"");
      break;
    case '\r':
      break;
    case '\\':
      printf("\\\\");
      break;
    case '"':
      printf("\\\"");
      break;
      /* These two case don't really require quoting:
	 case '\'':
	 printf("\\\'");
	 break;
	 case '\?':
	 printf("\\\?");
	 break;
      */
    case '\t':
      printf("\\t");
      break;
    case '\v':
      printf("\\v");
      break;
    case '\b':
      printf("\\b");
      break;
    case '\f':
      printf("\\f");
      break;
    case '\a':
      printf("\\a");
      break;
    default:
      putc(c, stdout);
    }
  }
  printf("\";\n\n%s\n",
	 "const char *get_stringified_file_contents() { return string; }");
  return 0;
}
