/*
 * A thread safe table of curves
 *
 * Copyright (c) 2003 by John D. Ramsdell. All rights reserved.
 *
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _TABLE_H
#define _TABLE_H

WX_DECLARE_LIST(Curve, Curve_list);

// This thread safe table of curves assumes that a curve is
// dynamically allocated, and that it is the table's responsibility to
// delete the curve whenever it is removed from the table.

class Table
{
public:
  Table();
  // Remove all curves from the table.
  void clear();
  // Adds a curve to the table.  If there is another curve in the
  // table with the same caption, it is deleted.  The argument to this
  // method must be a dynamically allocated curve.
  void add(Curve *);
  // Inserts a copy of the curves in the table into the given list.
  void insert_curves(Curve_list&);
  // Have the current curves been inserted into some list?
  bool have_curves_been_inserted();
private:
  bool m_inserted;
  Curve_list m_list;
  wxCriticalSection m_critical_section;
};

#endif
