/*
 * Transcript window
 *
 * Copyright (c) 2003 by John D. Ramsdell. All rights reserved.
 *
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <wx/wxprec.h>

#ifndef WX_PRECOMP
#include <wx/log.h>
#include <wx/panel.h>
#include <wx/textctrl.h>
#include <wx/sizer.h>
#include <wx/settings.h>
#endif

#include "transcript.hpp"

// Transcript size in character units
const int transcript_width = 80;
const int transcript_height = 20;

// Events and their IDs

enum
{
  id_text_ctrl = 1,
};

BEGIN_EVENT_TABLE(Transcript, wxPanel)
  EVT_TEXT_MAXLEN(id_text_ctrl, Transcript::on_text_maxlen)
END_EVENT_TABLE()

Transcript::Transcript(wxWindow *parent,
		       wxWindowID id,
		       const wxPoint& pos,
		       const wxSize& size,
		       long style,
		       const wxString& name)
  : wxPanel(parent, id, pos, size, style, name), m_maxed_out(FALSE)
{
  wxString message(wxT("Welcome to ") wxT(PACKAGE_STRING) wxT("\n\n"));

  m_text = new wxTextCtrl(this, id_text_ctrl, message,
			  wxDefaultPosition, wxDefaultSize,
			  wxTE_MULTILINE | wxTE_READONLY);
  m_text->SetFont(wxSystemSettings::GetFont(wxSYS_SYSTEM_FIXED_FONT));
  wxSize transcript_size(transcript_width * GetCharWidth(),
			 transcript_height * GetCharHeight());
  m_text->SetSize(transcript_size);
  wxBoxSizer *sizer = new wxBoxSizer(wxVERTICAL);
  sizer->Add(m_text,
	     1,			// make vertically stretchable
	     wxEXPAND | wxALL,	// make horizontally stretchable
				//   and make border all around
	     2);		// set border width
  SetSizer(sizer);
  sizer->SetSizeHints(this);
}

void Transcript::clear()
{
  m_text->Clear();
  if (m_maxed_out) {
    m_maxed_out = FALSE;
    wxLogMessage(wxT("The transcript window is empty"));
  }
}

void Transcript::append_text(const wxString& text)
{
  if (!m_maxed_out)
    m_text->AppendText(text);
}

void Transcript::on_text_maxlen(wxCommandEvent& WXUNUSED(event))
{
  if (!m_maxed_out) {
    m_maxed_out = TRUE;
    wxLogMessage(wxT("The transcript window is full"));
  }
}
