/*
 * wxCsound overview viewer -- displays HTML contained in a string
 *
 * Copyright (c) 2003 by John D. Ramsdell. All rights reserved.
 *
 * This software is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <wx/wxprec.h>

#ifndef WX_PRECOMP
#include <wx/wx.h>
#endif

#include <wx/html/htmlwin.h>
#include "viewer.hpp"
#include "overview.h"

// Viewer position in pixels
const int viewer_x_pos = 20;
const int viewer_y_pos = 20;

// Viewer size in character units
const int viewer_width = 80;
const int viewer_height = 30;

enum
{
  id_hide = 1,
};

class Viewer_frame: public wxFrame
{
public:
  Viewer_frame(Viewer *, wxWindow *);
  void on_hide(wxCommandEvent&); // Hide a viewer
  void on_close(wxCloseEvent&);	// Mark a viewer as destroyed
private:
  Viewer *m_viewer;
  DECLARE_EVENT_TABLE()
};

BEGIN_EVENT_TABLE(Viewer_frame, wxFrame)
  EVT_MENU(id_hide, Viewer_frame::on_hide)
  EVT_CLOSE(Viewer_frame::on_close)
END_EVENT_TABLE()

// Set up an HTML viewer within a frame.
Viewer_frame::Viewer_frame(Viewer *viewer, wxWindow *parent)
  : wxFrame(parent, -1, wxT(PACKAGE_NAME) wxT(" Viewer"),
	    wxPoint(viewer_x_pos, viewer_y_pos)),
  m_viewer(viewer)
{
  wxMenuBar *menuBar = new wxMenuBar;
  wxMenu *menu = new wxMenu;
  menu->Append(id_hide, wxT("&Close"),
	       wxT("Close overview window"));
  menuBar->Append(menu, wxT("&File"));
  SetMenuBar(menuBar);

  CreateStatusBar();

  wxHtmlWindow *htmlwin = new wxHtmlWindow(this);
  wxSize size(viewer_width * GetCharWidth(), viewer_height * GetCharHeight());
  htmlwin->SetSize(size);

  htmlwin->SetRelatedFrame(this, wxT("%s"));
  htmlwin->SetRelatedStatusBar(0);
  wxString content(get_stringified_file_contents(), wxConvUTF8);
  htmlwin->SetPage(content);

  wxBoxSizer *sizer = new wxBoxSizer(wxVERTICAL);
  sizer->Add(htmlwin, 1, wxEXPAND | wxALL, 2);
  SetSizer(sizer);
  sizer->SetSizeHints(this);
}

void Viewer_frame::on_hide(wxCommandEvent& WXUNUSED(event))
{
  Show(FALSE);
}

void Viewer_frame::on_close(wxCloseEvent& event)
{
  if (event.CanVeto()) {	// Try to hide instead of close,
    Show(FALSE);
    event.Veto();
  }
  else {			// else destroy viewer and mark it.
    m_viewer->close();
    Destroy();
  }
}

Viewer::Viewer(wxWindow *parent)
  : m_frame(new Viewer_frame(this, parent))
{
}

void Viewer::show()
{
  if (m_frame) {
    m_frame->Raise();
    m_frame->Show(TRUE);
  }
}

void Viewer::hide()
{
  if (m_frame)
    m_frame->Show(FALSE);
}

// Called when forced to destroy a viewer.
void Viewer::close()
{
  m_frame = 0;
}
